package cc.fascinated.common;

import lombok.experimental.UtilityClass;

import java.time.Instant;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.Date;

/**
 * @author Fascinated (fascinated7)
 */
@UtilityClass
public class DateUtils {

    private static final DateTimeFormatter FORMATTER = DateTimeFormatter.ISO_INSTANT;

    /**
     * Gets the date from a string.
     *
     * @param date The date string.
     * @return The date.
     */
    public static Date getDateFromString(String date) {
        return Date.from(Instant.from(FORMATTER.parse(date)));
    }

    /**
     * Aligns the date to the current hour.
     * <p>
     *     eg: 00:05 -> 00:00
     * </p>
     *
     * @param date The date to align.
     * @return The aligned date.
     */
    public static Date alignToCurrentHour(Date date) {
        return Date.from(Instant.ofEpochMilli(date.getTime()).truncatedTo(ChronoUnit.HOURS));
    }
}
