package cc.fascinated.controller;

import cc.fascinated.exception.impl.BadRequestException;
import cc.fascinated.model.user.User;
import cc.fascinated.model.user.UserDTO;
import cc.fascinated.services.UserService;
import lombok.NonNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * @author Fascinated (fascinated7)
 */
@RestController
@RequestMapping(value = "/users")
public class UserController {
    /**
     * The user service to use
     */
    @NonNull private final UserService userService;

    @Autowired
    public UserController(@NonNull UserService userService) {
        this.userService = userService;
    }

    /**
     * A GET mapping to retrieve a user by their steam id.
     *
     * @param id the id of the user
     * @return the user
     * @throws BadRequestException if the user is not found
     */
    @ResponseBody
    @GetMapping(value = "/{id}")
    public ResponseEntity<UserDTO> getUser(@PathVariable String id) {
        return ResponseEntity.ok(userService.getUser(id).getAsDTO());
    }
}
