package cc.fascinated.model.score;

import cc.fascinated.platform.Platform;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.Setter;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Date;

/**
 * @author Fascinated (fascinated7)
 */
@AllArgsConstructor
@Getter
@Setter
@Document("scores")
public class Score {
    /**
     * The ID of the score.
     * <p>
     * This is an internal ID to avoid clashing with other scores.
     * This is not the ID of the score on the platform.
     * </p>
     */
    @Id
    @JsonIgnore
    private final long id;

    /**
     * The ID of the player that set the score.
     */
    @Indexed @JsonIgnore
    private final String playerId;

    /**
     * The platform the score was set on.
     * <p>
     * eg: {@link Platform.Platforms#SCORESABER}
     * </p>
     */
    @Indexed
    @JsonIgnore
    private final Platform.Platforms platform;

    /**
     * The ID of the score of the platform it was set on.
     */
    @Indexed
    @JsonProperty("scoreId")
    private final String platformScoreId;

    /**
     * The ID of the leaderboard the score was set on.
     */
    @Indexed @JsonIgnore
    private final String leaderboardId;

    /**
     * The rank of the score when it was set.
     */
    private int rank;

    /**
     * The accuracy of the score in a percentage.
     */
    private final double accuracy;

    /**
     * The PP of the score.
     * <p>
     * e.g. 500pp
     * </p>
     */
    private double pp;

    /**
     * The score of the score.
     */
    private final int score;

    /**
     * The list of modifiers used in the score.
     */
    private final String[] modifiers;

    /**
     * The number of misses in the score.
     */
    private final int misses;

    /**
     * The number of bad cuts in the score.
     */
    private final int badCuts;

    /**
     * The timestamp of when the score was set.
     */
    private final Date timestamp;
}
