package cc.fascinated.repository;

import cc.fascinated.model.user.User;
import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.data.mongodb.repository.Query;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

/**
 * @author Fascinated (fascinated7)
 */
public interface UserRepository extends MongoRepository<User, UUID> {
    /**
     * Finds a user by their steam id.
     *
     * @param steamId the steam id of the user
     * @return the user
     */
    Optional<User> findBySteamId(String steamId);

    /**
     * Fetches all users and only their steam ids.
     *
     * @return the list of users
     */
    @Query(value = "{}", fields = "{ 'steamId' : 1 }")
    List<User> fetchOnlySteamIds();

    /**
     * Finds a user by their username.
     *
     * @param username the username of the user
     * @return the user
     */
    @Query("{ $text: { $search: ?0 } }")
    List<User> findUsersByUsername(String username);
}
