package cc.fascinated.services;

import cc.fascinated.model.Counter;
import cc.fascinated.repository.CounterRepository;
import lombok.AllArgsConstructor;
import lombok.Getter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Optional;

/**
 * @author Fascinated (fascinated7)
 */
@Service
public class CounterService {
    /**
     * The counter repository to use.
     */
    private final CounterRepository counterRepository;

    @Autowired
    public CounterService(CounterRepository counterRepository) {
        this.counterRepository = counterRepository;
    }

    /**
     * Gets the next number in the sequence.
     *
     * @param type The type of the counter.
     * @return The next number in the sequence.
     */
    public long getNext(CounterType type) {
        Optional<Counter> counterOptional = counterRepository.findById(type.getId());
        Counter counter = counterOptional.orElseGet(() -> new Counter(type.getId(), 1));

        long current = counter.getNext();
        counter.setNext(current + 1);

        counterRepository.save(counter);
        return current;
    }

    @AllArgsConstructor
    @Getter
    public enum CounterType {
        SCORE("score");

        /**
         * The ID of the counter.
         */
        private final String id;
    }
}